# Touch response: タッチ応答

`touch_response (タッチ応答)`プラグインはディスプレイを行と列に分割することで、タッチ応答(またはマウスによるクリック)を簡単に受け取ることができます。 各応答は、左から右、上から下へのカウントに対応する単一の数字でエンコードされます。 たとえば、3行2列を指定した場合、ディスプレイは次の応答領域に分割されます:

	1	2
	3	4
	5	6

同様に、1行4列と指定した場合、ディスプレイは水平方向に次の応答領域に分割されます:

	1	2	3	4
